@@ -8,9 +8,9 @@ library(pbdZMQ, quietly = TRUE)
 
 ### Initial.
 context <- zmq.ctx.new()
-sender <- zmq.socket(context, .pbdZMQEnv$ZMQ.ST$PUSH)
+sender <- zmq.socket(context, .pbd_env$ZMQ.ST$PUSH)
 zmq.bind(sender, "tcp://*:5557")
-sink <- zmq.socket(context, .pbdZMQEnv$ZMQ.ST$PUSH)
+sink <- zmq.socket(context, .pbd_env$ZMQ.ST$PUSH)
 zmq.connect(sink, "tcp://localhost:5558")
 
 ### Send sink.
