@@ -7,7 +7,7 @@ library(pbdZMQ, quietly = TRUE)
 
 ### Initial.
 context <- zmq.ctx.new()
-publisher <- zmq.socket(context, .pbdZMQEnv$ZMQ.ST$PUB)
+publisher <- zmq.socket(context, .pbd_env$ZMQ.ST$PUB)
 zmq.bind(publisher, "tcp://*:5556")
 if(.Platform$OS.type != "windows"){  # Windows does not support ipc.
   zmq.bind(publisher, "ipc://weather.ipc")
